@@ -18,6 +18,7 @@ from os.path import abspath, dirname, join
 base_path = abspath(dirname(__file__))
 import sys
 sys.path.insert(0, abspath(join(base_path, 'utils')))
+sys.path.insert(0, abspath(join(base_path, 'lib')))
 
 def get_modules(prefix, parent):
     if not os.path.isfile(os.path.join(parent, '__init__.py')):
@@ -133,7 +134,7 @@ def make_application(app, debug=False, wsgi=False):
     if hasattr(app, 'settings'):
         conf = app.settings
     else:
-        conf = Yaml_Config(os.path.join(app_path, 'settings.yaml'))
+        conf = Yaml_Config(app_path, os.path.join(app_path, 'settings.yaml'))
     views_path = os.path.join(app_path, 'views')
     for module, name in get_modules([app.__name__, 'views'], views_path):
         if type(module) == tuple:
